==> cljs-time-0.5.0.jar: cljs_test/generated_test_suite.out/cljs_time/extend.js <==
// Compiled by ClojureScript 1.9.521 {:static-fns true, :optimize-constants true, :target :nodejs}
goog.provide('cljs_time.extend');
goog.require('cljs.core');
goog.require('cljs.core.constants');
goog.require('goog.date.Date');
goog.require('goog.date.DateTime');
goog.require('goog.date.UtcDateTime');
goog.require('cljs_time.core');
cljs_time.extend.hash_parts = (function cljs_time$extend$hash_parts(type_hash,ms_since_epoch,offset){
var ms_shifted = (ms_since_epoch * (100000));
var adj_offset = (offset + (720));
var type_offset = (type_hash * (10000));
return ((ms_shifted + adj_offset) + type_offset);
});
goog.date.Date.prototype.cljs$core$IEquiv$ = cljs.core.PROTOCOL_SENTINEL;

goog.date.Date.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (o,other){
var o__$1 = this;
var and__7179__auto__ = (other instanceof goog.date.Date);
if(and__7179__auto__){
return o__$1.equals(other);
} else {
return and__7179__auto__;
}
});

goog.date.Date.prototype.cljs$core$IHash$ = cljs.core.PROTOCOL_SENTINEL;

goog.date.Date.prototype.cljs$core$IHash$_hash$arity$1 = (function (this$){
var this$__$1 = this;
return cljs_time.extend.hash_parts((1),this$__$1.getTime(),this$__$1.getTimezoneOffset());
});

goog.date.Date.prototype.cljs$core$IComparable$ = cljs.core.PROTOCOL_SENTINEL;

goog.date.Date.prototype.cljs$core$IComparable$_compare$arity$2 = (function (o,other){
var o__$1 = this;
return cljs_time.core.compare_local_dates(o__$1,other);
});
goog.date.DateTime.prototype.cljs$core$IEquiv$ = cljs.core.PROTOCOL_SENTINEL;

goog.date.DateTime.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (o,other){
var o__$1 = this;
return ((other instanceof goog.date.DateTime)) && ((o__$1.getTime() === other.getTime())) && ((o__$1.getTimezoneOffset() === other.getTimezoneOffset()));
});

goog.date.DateTime.prototype.cljs$core$IHash$ = cljs.core.PROTOCOL_SENTINEL;

goog.date.DateTime.prototype.cljs$core$IHash$_hash$arity$1 = (function (this$){
var this$__$1 = this;
return cljs_time.extend.hash_parts((2),this$__$1.getTime(),this$__$1.getTimezoneOffset());
});

goog.date.DateTime.prototype.cljs$core$IComparable$ = cljs.core.PROTOCOL_SENTINEL;

goog.date.DateTime.prototype.cljs$core$IComparable$_compare$arity$2 = (function (o,other){
var o__$1 = this;
return (o__$1.getTime() - other.getTime());
});
goog.date.UtcDateTime.prototype.cljs$core$IEquiv$ = cljs.core.PROTOCOL_SENTINEL;

goog.date.UtcDateTime.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (o,other){
var o__$1 = this;
return ((other instanceof goog.date.UtcDateTime)) && ((o__$1.getTime() === other.getTime())) && ((o__$1.getTimezoneOffset() === other.getTimezoneOffset()));
});

goog.date.UtcDateTime.prototype.cljs$core$IHash$ = cljs.core.PROTOCOL_SENTINEL;

goog.date.UtcDateTime.prototype.cljs$core$IHash$_hash$arity$1 = (function (this$){
var this$__$1 = this;
return cljs_time.extend.hash_parts((3),this$__$1.getTime(),this$__$1.getTimezoneOffset());
});

goog.date.UtcDateTime.prototype.cljs$core$IComparable$ = cljs.core.PROTOCOL_SENTINEL;

goog.date.UtcDateTime.prototype.cljs$core$IComparable$_compare$arity$2 = (function (o,other){
var o__$1 = this;
return (o__$1.getTime() - other.getTime());
});

==> cljs-time-0.5.0-20170303.221550-1.jar: cljs_test/generated_test_suite.out/cljs_time/extend.js <==
// Compiled by ClojureScript 1.9.89 {:static-fns true, :optimize-constants true, :target :nodejs}
goog.provide('cljs_time.extend');
goog.require('cljs.core');
goog.require('goog.date.Date');
goog.require('goog.date.DateTime');
goog.require('goog.date.UtcDateTime');
cljs_time.extend.hash_parts = (function cljs_time$extend$hash_parts(type_hash,ms_since_epoch,offset){
var ms_shifted = (ms_since_epoch * (100000));
var adj_offset = (offset + (720));
var type_offset = (type_hash * (10000));
return ((ms_shifted + adj_offset) + type_offset);
});
goog.date.Date.prototype.cljs$core$IEquiv$ = true;

goog.date.Date.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (o,other){
var o__$1 = this;
var and__6534__auto__ = (other instanceof goog.date.Date);
if(and__6534__auto__){
return o__$1.equals(other);
} else {
return and__6534__auto__;
}
});

goog.date.Date.prototype.cljs$core$IHash$ = true;

goog.date.Date.prototype.cljs$core$IHash$_hash$arity$1 = (function (this$){
var this$__$1 = this;
return cljs_time.extend.hash_parts((1),this$__$1.getTime(),this$__$1.getTimezoneOffset());
});

goog.date.Date.prototype.cljs$core$IComparable$ = true;

goog.date.Date.prototype.cljs$core$IComparable$_compare$arity$2 = (function (o,other){
var o__$1 = this;
var yo = o__$1.getYear();
var yother = other.getYear();
var dayo = o__$1.getDayOfYear();
var dayother = other.getDayOfYear();
if(cljs.core.not_EQ_.cljs$core$IFn$_invoke$arity$2(yo,yother)){
return (yo - yother);
} else {
if(cljs.core.not_EQ_.cljs$core$IFn$_invoke$arity$2(dayo,dayother)){
return (dayo - dayother);
} else {
return (0);

}
}
});
goog.date.DateTime.prototype.cljs$core$IEquiv$ = true;

goog.date.DateTime.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (o,other){
var o__$1 = this;
return ((other instanceof goog.date.DateTime)) && ((o__$1.getTime() === other.getTime())) && ((o__$1.getTimezoneOffset() === other.getTimezoneOffset()));
});

goog.date.DateTime.prototype.cljs$core$IHash$ = true;

goog.date.DateTime.prototype.cljs$core$IHash$_hash$arity$1 = (function (this$){
var this$__$1 = this;
return cljs_time.extend.hash_parts((2),this$__$1.getTime(),this$__$1.getTimezoneOffset());
});

goog.date.DateTime.prototype.cljs$core$IComparable$ = true;

goog.date.DateTime.prototype.cljs$core$IComparable$_compare$arity$2 = (function (o,other){
var o__$1 = this;
return (o__$1.getTime() - other.getTime());
});
goog.date.UtcDateTime.prototype.cljs$core$IEquiv$ = true;

goog.date.UtcDateTime.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (o,other){
var o__$1 = this;
return ((other instanceof goog.date.UtcDateTime)) && ((o__$1.getTime() === other.getTime())) && ((o__$1.getTimezoneOffset() === other.getTimezoneOffset()));
});

goog.date.UtcDateTime.prototype.cljs$core$IHash$ = true;

goog.date.UtcDateTime.prototype.cljs$core$IHash$_hash$arity$1 = (function (this$){
var this$__$1 = this;
return cljs_time.extend.hash_parts((3),this$__$1.getTime(),this$__$1.getTimezoneOffset());
});

goog.date.UtcDateTime.prototype.cljs$core$IComparable$ = true;

goog.date.UtcDateTime.prototype.cljs$core$IComparable$_compare$arity$2 = (function (o,other){
var o__$1 = this;
return (o__$1.getTime() - other.getTime());
});
